==> optionsview-0.0.1.tar.gz: optionsview-0.0.1/options/headers.py <==
__straddle_headers = [
    'inTheMoney_call',
    'openInterest_call', 'impliedVolatility_call',
    'volume_call',
    'change_call', 'percentChange_call',
    'lastPrice_call', 'bid_call', 'ask_call',
    'strike',
    'expire_date',
    'bid_put', 'ask_put',
    'lastPrice_put',
    'change_put', 'percentChange_put',
    'volume_put',
    'openInterest_put', 'impliedVolatility_put',
    'inTheMoney_put',
    'contractSize_call', 'contractSymbol_call', 'lastTradeDate_call', 'currency_call',
    'contractSize_put', 'contractSymbol_put', 'lastTradeDate_put', 'currency_put'
]

final_headers = {
    'inTheMoney_call': 'itm_call',
    'openInterest_call': 'open_interest_call',
    'impliedVolatility_call': 'imp_vol_call',
    'volume_call': 'volume_call',
    'change_call': 'change_call',
    'percentChange_call': 'percent_change_call',
    'lastPrice_call': 'last_price_call',
    'bid_call': 'bid_call',
    'ask_call': 'ask_call',
    'strike': 'strike',
    'expire_date': 'expire_date',
    'bid_put': 'bid_put',
    'ask_put': 'ask_put',
    'lastPrice_put': 'last_price_put',
    'change_put': 'change_put',
    'percentChange_put': 'percent_change_put',
    'volume_put': 'volume_put',
    'openInterest_put': 'open_interest_put',
    'impliedVolatility_put': 'imp_vol_call',
    'inTheMoney_put': 'itm_put',
    'contractSize_call': 'contract_size_call',
    'contractSymbol_call': 'contract_symbol_call',
    'lastTradeDate_call': 'last_trade_date_call',
    'currency_call': 'currency_call',
    'contractSize_put': 'contract_size_put',
    'contractSymbol_put': 'contract_symbol_put',
    'lastTradeDate_put': 'last_trade_date_put',
    'currency_put': 'currency_put'
}

==> optionsview-0.0.2.tar.gz: optionsview-0.0.2/options/headers.py <==
__straddle_headers = [
    'inTheMoney_call',
    'openInterest_call', 'impliedVolatility_call',
    'volume_call',
    'change_call', 'percentChange_call',
    'lastPrice_call', 'bid_call', 'ask_call',
    'strike',
    'expire_date',
    'bid_put', 'ask_put',
    'lastPrice_put',
    'change_put', 'percentChange_put',
    'volume_put',
    'openInterest_put', 'impliedVolatility_put',
    'inTheMoney_put',
    'contractSize_call', 'contractSymbol_call', 'lastTradeDate_call', 'currency_call',
    'contractSize_put', 'contractSymbol_put', 'lastTradeDate_put', 'currency_put'
]

final_headers = {
    'inTheMoney_call': 'itm_call',
    'openInterest_call': 'open_interest_call',
    'impliedVolatility_call': 'imp_vol_call',
    'volume_call': 'volume_call',
    'change_call': 'change_call',
    'percentChange_call': 'percent_change_call',
    'lastPrice_call': 'last_price_call',
    'bid_call': 'bid_call',
    'ask_call': 'ask_call',
    'strike': 'strike',
    'expire_date': 'expire_date',
    'bid_put': 'bid_put',
    'ask_put': 'ask_put',
    'lastPrice_put': 'last_price_put',
    'change_put': 'change_put',
    'percentChange_put': 'percent_change_put',
    'volume_put': 'volume_put',
    'openInterest_put': 'open_interest_put',
    'impliedVolatility_put': 'imp_vol_call',
    'inTheMoney_put': 'itm_put',
    'contractSize_call': 'contract_size_call',
    'contractSymbol_call': 'contract_symbol_call',
    'lastTradeDate_call': 'last_trade_date_call',
    'currency_call': 'currency_call',
    'contractSize_put': 'contract_size_put',
    'contractSymbol_put': 'contract_symbol_put',
    'lastTradeDate_put': 'last_trade_date_put',
    'currency_put': 'currency_put',
    'option_type': 'option_type',
    'symbol': 'symbol',
    'contractSymbol': 'contract_symbol',
    'lastTradeDate': 'last_trade_date',
    'lastPrice': 'last_price',
    'bid': 'bid',
    'ask': 'ask',
    'change': 'change',
    'percentChange': 'percent_change',
    'volume': 'volume',
    'openInterest': 'open_interest',
    'impliedVolatility': 'imp_vol',
    'inTheMoney': 'itm',
    'contractSize': 'contract_size',
    'currency': 'currency',

}
